@@ -95,8 +95,7 @@ class Column:
             "validation":self.validation.summary(),
             "sql_data":self.data.summary(),
         }
-        if self.relationship is not None:
-            value["relationship"] = self.relationship.summary
+
         return value
 
 
@@ -162,32 +161,32 @@ class Column:
         }
         return value
 
-    @property
-    def relationship(self)->_db_relationship_type:
-        '''
-            Get this Column's relationship instance, if it has one.
+    # @property
+    # def relationship(self)->_db_relationship_type:
+    #     '''
+    #         Get this Column's relationship instance, if it has one.
 
-            `default`:None
+    #         `default`:None
 
-            Meta
-            ----------
-            `@author`: Colemen Atwood
-            `@created`: 12-16-2022 11:05:43
-            `@memberOf`: Column
-            `@property`: relationship
-        '''
-        value = self._relationship
-        if value is None:
-            if self.data.is_foreign_key is True:
-                _log("Column.relationship --- Relationship Found","magenta")
-                value = _rel.Relationship(
-                    self.database,
-                    self.table,
-                    self,
-                    self.data.foreign_key_data
-                )
-                self._relationship = value
-        return value
+    #         Meta
+    #         ----------
+    #         `@author`: Colemen Atwood
+    #         `@created`: 12-16-2022 11:05:43
+    #         `@memberOf`: Column
+    #         `@property`: relationship
+    #     '''
+    #     value = self._relationship
+    #     if value is None:
+    #         if self.data.is_foreign_key is True:
+    #             _log("Column.relationship --- Relationship Found","magenta")
+    #             value = _rel.Relationship(
+    #                 self.database,
+    #                 self.table,
+    #                 self,
+    #                 self.data.foreign_key_data
+    #             )
+    #             self._relationship = value
+    #     return value
 
     @dataclass
     class sql_data:
