@@ -128,8 +128,8 @@ class Table:
             populate_from_dict(data,self)
 
         self.raw_fulltext_indexes = self.database.get_fulltext_indexes_by_table(self.name)
-        if self.raw_referential_constraints is None:
-            self.raw_referential_constraints = _lu.force_list(self.database.get_referential_constraint_by_table(self.name))
+        # if self.raw_referential_constraints is None:
+        #     self.raw_referential_constraints = _lu.force_list(self.database.get_referential_constraint_by_table(self.name))
         
         # @Mstep [] register this table with the database.
         self.database.register(self)
@@ -234,8 +234,8 @@ class Table:
         value['relationships'] = [x.summary for x in self._relationships]
         value['total_columns'] = len(self.columns)
         value['total_relationships'] = len(self._relationships)
-        value['total_raw_referential_constraints'] = len(self.raw_referential_constraints)
-        value['total_raw_fulltext_indexes'] = len(self.raw_fulltext_indexes)
+        # value['total_raw_referential_constraints'] = len(self.raw_referential_constraints)
+        # value['total_raw_fulltext_indexes'] = len(self.raw_fulltext_indexes)
 
         # self._cache.set_key("columns",value['columns'])
         # value['end_points'] = [x.summary for x in self._end_point_docs]
