@@ -16,10 +16,14 @@ from colemen_utilities.database_utils.MySQL.SelectQuery import *
 from colemen_utilities.database_utils.MySQL.UpdateQuery import *
 from colemen_utilities.database_utils.MySQL.DeleteQuery import *
 from colemen_utilities.database_utils.MySQL.Table import *
+from colemen_utilities.database_utils.MySQL.Relationship import *
 
+from colemen_utilities.database_utils.MySQL.DatabaseManager import *
 from colemen_utilities.database_utils.MySQL.MySQLDatabase import MySQLDatabase as MySQL
 from colemen_utilities.database_utils.MySQL.MySQLDatabase import new
 
+
+_db_mysql_manager_type = None
 _db_mysql_database_type = None
 _db_column_type = None
 _db_column_sql_data_type = None
@@ -30,6 +34,7 @@ _db_mysql_select_query_type = None
 _db_mysql_update_query_type = None
 _db_mysql_delete_query_type = None
 _db_table_type = None
+_db_relationship_type = None
 
 if TYPE_CHECKING:
     import colemen_utilities.database_utils.MySQL.MySQLDatabase as _mysqldb
@@ -46,6 +51,9 @@ if TYPE_CHECKING:
     import colemen_utilities.database_utils.MySQL.Table.Table as _table
     _db_table_type = _TypeVar('_db_table_type', bound=_table.Table)
 
+    import colemen_utilities.database_utils.MySQL.Relationship.Relationship as _rel
+    _db_relationship_type = _TypeVar('_db_relationship_type', bound=_rel.Relationship)
+
 
     import colemen_utilities.database_utils.MySQL.DeleteQuery as _deleteQuery
     _db_mysql_delete_query_type = _TypeVar('_db_mysql_delete_query_type', bound=_deleteQuery.DeleteQuery)
@@ -58,3 +66,6 @@ if TYPE_CHECKING:
 
     import colemen_utilities.database_utils.MySQL.InsertQuery as _insertQuery
     _db_mysql_insert_query_type = _TypeVar('_db_mysql_insert_query_type', bound=_insertQuery.InsertQuery)
+
+    import colemen_utilities.database_utils.MySQL.DatabaseManager as _mysql_dbm
+    _db_mysql_manager_type = _TypeVar('_db_mysql_manager_type', bound=_mysql_dbm.DatabaseManager)
